##
## Chemical Biophysics Symposium, 2023
## Erik Spence
## Introduction to Neural Networks

#######################################################


import tensorflow.keras.models as km
import tensorflow.keras.layers as kl


#######################################################


## A function to build a Keras model for our first neural network
## example.
def build_model(numfm, numnodes):
    
    ## Initialize an empty model.
    model = km.Sequential()
    
    ## Add the convolutional layer.
    model.add(kl.Conv2D(numfm, kernel_size = (5, 5),
                        input_shape = (28, 28, 1),
                        activation = 'relu'))

    ## Add the max-pooling layer.
    model.add(kl.MaxPooling2D(pool_size = (2, 2),
                              strides = (2, 2)))

    ## Add another convolutional layer, with twice as many feature
    ## maps and a smaller kernel size.
    model.add(kl.Conv2D(2 * numfm, kernel_size = (3, 3),
                        activation = 'relu'))

    ## Add another max-pooling layer.
    model.add(kl.MaxPooling2D(pool_size = (2, 2),
                              strides = (2, 2)))
    
    ## Flatten the data so that it can be fed into the first
    ## fully-connected ('dense') layer.
    model.add(kl.Flatten())

    ## Add a fully-connected layer.
    model.add(kl.Dense(numnodes, activation = 'tanh'))

    ## Add the output layer.
    model.add(kl.Dense(10, activation = 'softmax'))

    ## Return the model.
    return model


#######################################################
